@@ -84,7 +84,11 @@ class KML(object):
 
     def from_string(self, xml_string):
         """ create a KML object from a xml string"""
-        element = etree.XML(xml_string)
+        if config.LXML:
+            element = etree.fromstring(xml_string, parser=etree.XMLParser(huge_tree=True))
+        else:
+            element = etree.XML(xml_string)
+
         if element.tag.endswith('kml'):
             ns = element.tag.rstrip('kml')
             documents = element.findall('%sDocument' % ns)
